@@ -10,14 +10,14 @@ def create_data_entity(filePath, jsonData):
     headers = get_header(filePath, 'key')
     dataDto = DataEntity(
         preData=jsonData['data'],
-        pluginDataConfig=json.dumps(jsonData['pluginDataConfig']),
+        pluginDataConfig=jsonData['pluginDataConfig'],
         taskInstanceId=1111,
         taskId=1,
         nodeId=1,
         logId=1,
         serverName=serverName,
         headers=headers,
-        prjId=json.dumps(jsonData['prjId']),
+        prjId=int(json.dumps(jsonData.get('prjId', 1))),
         tenantId=1,
         bootstrapServers='1',
     )
